/*! For license information please see chunk.2957c977d18ba6e12802.js.LICENSE.txt */
(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[993],{1275:function(e,n,r){"use strict";r.d(n,{l:function(){return a}});var t=r(94707),o=new WeakMap,a=(0,t.XM)((function(e,n){return function(r){var t=o.get(r);if(Array.isArray(e)){if(Array.isArray(t)&&t.length===e.length&&e.every((function(e,n){return e===t[n]})))return}else if(t===e&&(void 0!==e||o.has(r)))return;r.setValue(n()),o.set(r,Array.isArray(e)?Array.from(e):e)}}))},83278:function(e,n,r){"use strict";r.d(n,{r:function(){return v}});var t=r(94707);function o(e,n){var r;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(r=function(e,n){if(!e)return;if("string"==typeof e)return a(e,n);var r=Object.prototype.toString.call(e).slice(8,-1);"Object"===r&&e.constructor&&(r=e.constructor.name);if("Map"===r||"Set"===r)return Array.from(e);if("Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return a(e,n)}(e))||n&&e&&"number"==typeof e.length){r&&(e=r);var t=0,o=function(){};return{s:o,n:function(){return t>=e.length?{done:!0}:{done:!1,value:e[t++]}},e:function(e){throw e},f:o}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,u=!0,f=!1;return{s:function(){r=e[Symbol.iterator]()},n:function(){var e=r.next();return u=e.done,e},e:function(e){f=!0,i=e},f:function(){try{u||null==r.return||r.return()}finally{if(f)throw i}}}}function a(e,n){(null==n||n>e.length)&&(n=e.length);for(var r=0,t=new Array(n);r<n;r++)t[r]=e[r];return t}var i=function(e,n){var r=e.startNode.parentNode,o=void 0===n?e.endNode:n.startNode,a=r.insertBefore((0,t.IW)(),o);r.insertBefore((0,t.IW)(),o);var i=new t.nt(e.options);return i.insertAfterNode(a),i},u=function(e,n){return e.setValue(n),e.commit(),e},f=function(e,n,r){var o=e.startNode.parentNode,a=r?r.startNode:e.endNode,i=n.endNode.nextSibling;i!==a&&(0,t.V)(o,n.startNode,i,a)},s=function(e){(0,t.r4)(e.startNode.parentNode,e.startNode,e.endNode.nextSibling)},l=function(e,n,r){for(var t=new Map,o=n;o<=r;o++)t.set(e[o],o);return t},c=new WeakMap,d=new WeakMap,v=(0,t.XM)((function(e,n,r){var a;return void 0===r?r=n:void 0!==n&&(a=n),function(n){if(!(n instanceof t.nt))throw new Error("repeat can only be used in text bindings");var v,y,h,p=c.get(n)||[],g=d.get(n)||[],b=[],m=[],N=[],w=0,A=o(e);try{for(A.s();!(v=A.n()).done;){var S=v.value;N[w]=a?a(S,w):w,m[w]=r(S,w),w++}}catch(B){A.e(B)}finally{A.f()}for(var k=0,M=p.length-1,I=0,W=m.length-1;k<=M&&I<=W;)if(null===p[k])k++;else if(null===p[M])M--;else if(g[k]===N[I])b[I]=u(p[k],m[I]),k++,I++;else if(g[M]===N[W])b[W]=u(p[M],m[W]),M--,W--;else if(g[k]===N[W])b[W]=u(p[k],m[W]),f(n,p[k],b[W+1]),k++,W--;else if(g[M]===N[I])b[I]=u(p[M],m[I]),f(n,p[M],p[k]),M--,I++;else if(void 0===y&&(y=l(N,I,W),h=l(g,k,M)),y.has(g[k]))if(y.has(g[M])){var x=h.get(N[I]),_=void 0!==x?p[x]:null;if(null===_){var j=i(n,p[k]);u(j,m[I]),b[I]=j}else b[I]=u(_,m[I]),f(n,_,p[k]),p[x]=null;I++}else s(p[M]),M--;else s(p[k]),k++;for(;I<=W;){var C=i(n,b[W+1]);u(C,m[I]),b[I++]=C}for(;k<=M;){var V=p[k++];null!==V&&s(V)}c.set(n,b),d.set(n,N)}}))}}]);
//# sourceMappingURL=chunk.2957c977d18ba6e12802.js.map